% screen output
disp ' '
disp ' '
disp 'Compute Value and Policy Functions for Inflation Zone Targeting'
disp ' '
disp 'Reproduce Fig. 4 of Orphanides and Wieland (2000),'
disp 'but with "low variance" instead of perfect certainty!'
disp '(parameter values US-CBO annual data 1960-98)'
disp '---------------------------------------------------------------'
disp ' '

disp '1 of 7, Linear-Quadratic Model:'
% clear workspace, start timer
clear all; tic
% settings
multflag=1; poliflag=1; philflag=1; prefflag=1; striflag=0; shocflag=0;
flags=[multflag poliflag philflag prefflag striflag shocflag];
% compute optimal policies, save results, read timer
us12ghxx; save fig4_lq
fprintf('  Elapsed Time = %7.2f Seconds\n',toc)
disp ' '

disp '2 of 7, Linear-ZoneQuadratic Model / with low variance:'
% clear workspace, start timer
clear all; tic
% settings
multflag=1; poliflag=1; philflag=1; prefflag=0; striflag=0; shocflag=-1;
flags=[multflag poliflag philflag prefflag striflag shocflag];
% compute optimal policies, save results, read timer
us12ghxx; save fig4a_lzq
fprintf('  Elapsed Time = %7.2f Seconds\n',toc)
disp ' '

disp '3 of 7, Linear-ZoneQuadratic Model / price shocks only:'
% clear workspace, start timer
clear all; tic
% settings
multflag=1; poliflag=1; philflag=1; prefflag=0; striflag=0; shocflag=1;
flags=[multflag poliflag philflag prefflag striflag shocflag];
% compute optimal policies, save results, read timer
us12ghxx; save fig4a_lzq_p
fprintf('  Elapsed Time = %7.2f Seconds\n',toc)
disp ' '

disp '4 of 7, Linear-ZoneQuadratic Model / price and demand shocks:'
% clear workspace, start timer
clear all; tic
% settings
multflag=1; poliflag=1; philflag=1; prefflag=0; striflag=0; shocflag=2;
flags=[multflag poliflag philflag prefflag striflag shocflag];
% compute optimal policies, save results, read timer
us12ghxx; save fig4a_lzq_pd
fprintf('  Elapsed Time = %7.2f Seconds\n',toc)
disp ' '

disp '5 of 7, ZoneLinear-Quadratic Model / with low variance:'
% clear workspace, start timer
clear all; tic
% settings
multflag=1; poliflag=1; philflag=0; prefflag=1; striflag=0; shocflag=-1;
flags=[multflag poliflag philflag prefflag striflag shocflag];
% compute optimal policies, save results, read timer
us12ghxx; save fig4b_zlq
fprintf('  Elapsed Time = %7.2f Seconds\n',toc)
disp ' '

disp '6 of 7, ZoneLinear-Quadratic Model / price shocks only:'
% clear workspace, start timer
clear all; tic
% settings
multflag=1; poliflag=1; philflag=0; prefflag=1; striflag=0; shocflag=1;
flags=[multflag poliflag philflag prefflag striflag shocflag];
% compute optimal policies, save results, read timer
us12ghxx; save fig4b_zlq_p
fprintf('  Elapsed Time = %7.2f Seconds\n',toc)
disp ' '

disp '7 of 7, ZoneLinear-Quadratic Model / price and demand shocks:'
% clear workspace, start timer
clear all; tic
% settings
multflag=1; poliflag=1; philflag=0; prefflag=1; striflag=0; shocflag=2;
flags=[multflag poliflag philflag prefflag striflag shocflag];
% compute optimal policies, save results, read timer
us12ghxx; save fig4b_zlq_pd
fprintf('  Elapsed Time = %7.2f Seconds\n',toc)
disp ' '

% plot figure 
figure(4)

subplot(2,2,1);
hold on; clear all; load fig4_lq;     plot(pilag,hfin);      hold off
hold on; clear all; load fig4a_lzq;   plot(pilag,hfin,'--'); hold off
hold on; clear all; load fig4a_lzq_p; plot(pilag,hfin,'.:'); hold off
title('price shocks only')
xlabel('inflation gap')
ylabel('intended output gap')
xlim([-4 4]); ylim([-4 4])
grid on

subplot(2,2,3);
hold on; clear all; load fig4_lq;      plot(pilag,hfin);      hold off
hold on; clear all; load fig4a_lzq;    plot(pilag,hfin,'--'); hold off
hold on; clear all; load fig4a_lzq_pd; plot(pilag,hfin,'.:'); hold off
title('price and demand shocks')
xlabel('inflation gap')
ylabel('intended output gap')
xlim([-4 4]); ylim([-4 4])
grid on

subplot(2,2,2);
hold on; clear all; load fig4_lq;     plot(pilag,hfin);      hold off
hold on; clear all; load fig4b_zlq;   plot(pilag,hfin,'--'); hold off
hold on; clear all; load fig4b_zlq_p; plot(pilag,hfin,'.:'); hold off
title('price shocks only')
xlabel('inflation gap')
ylabel('intended output gap')
xlim([-4 4]); ylim([-4 4])
grid on

subplot(2,2,4);
hold on; clear all; load fig4_lq;      plot(pilag,hfin);      hold off
hold on; clear all; load fig4b_zlq;    plot(pilag,hfin,'--'); hold off
hold on; clear all; load fig4b_zlq_pd; plot(pilag,hfin,'.:'); hold off
title('price and demand shocks')
xlabel('inflation gap')
ylabel('intended output gap')
xlim([-4 4]); ylim([-4 4])
grid on