function finit=val12ghxxinit(x,parameter,p,PSH,YSH,weip,weiy,flags);
%-------------------
% USED BY: us12ghxx
%-------------------

% possible parameter values:
% linear Phillips curve
alpha=parameter(1);
% nonlinear Phillips curve
zeta=parameter(2);
alphaz=parameter(3);
% IS curve
rho=parameter(4); 
ksi=parameter(5);
rbar=parameter(6);
% loss function
omega=parameter(7); 
beta=parameter(8);
pitarg=parameter(9);
zetapr=parameter(10);
% variance of shocks
sigmap=parameter(11);
sigmay=parameter(12);

% settings
philflag=flags(3);
prefflag=flags(4);
shocflag=flags(6);

% quadrature weights
wei=weip;
    
% linear Phillips curve, quadratic objective function
% L-Q
if philflag==1 & prefflag==1
    % price and demand shocks
    if shocflag==2 | -1
        pp=p+alpha.*(x+YSH)+PSH;
        finit=(((omega.*(pp-pitarg).^2+(1-omega).*(x+YSH).^2)*wei)'*wei)./pi;
    % price shocks only    
    elseif shocflag==1
        pp=p+alpha.*x+PSH;
        finit=((omega.*(pp-pitarg).^2+(1-omega).*x.^2)'*wei)./sqrt(pi);
    % without uncertainty    
    elseif shocflag==0
        pp=p+alpha.*x;
        finit=(omega.*(pp-pitarg).^2+(1-omega).*x.^2);
    end
end

% linear Phillips curve, zone-quadratic objective function
% L-ZQ
if philflag==1 & prefflag==0
    % price and demand shocks
    if shocflag==2 | -1
        pp=p+alpha.*(x+YSH)+PSH;
        c=0.1;
        ppart1=c+(pp+zetapr/2).^2;
        ppart2=c+(-pp+zetapr/2).^2;
        ppzone=pp-0.5*sqrt(ppart1)+0.5*sqrt(ppart2);
        finit=(((omega.*(ppzone-pitarg).^2+(1-omega).*(x+YSH).^2)*wei)'*wei)./pi;
    % price shocks only    
    elseif shocflag==1
        pp=p+alpha.*x+PSH;
        c=0.1;
        ppart1=c+(pp+zetapr/2).^2;
        ppart2=c+(-pp+zetapr/2).^2;
        ppzone=pp-0.5*sqrt(ppart1)+0.5*sqrt(ppart2);
        finit=((omega.*(ppzone-pitarg).^2+(1-omega).*x.^2)'*wei)./sqrt(pi);
    % without uncertainty    
    elseif shocflag==0
        pp=p+alpha.*x;
        c=0.1;
        ppart1=c+(pp+zetapr/2).^2;
        ppart2=c+(-pp+zetapr/2).^2;
        ppzone=pp-0.5*sqrt(ppart1)+0.5*sqrt(ppart2);
        finit=(omega.*(ppzone-pitarg).^2+(1-omega).*x.^2);
    end
end

% zone-linear Phillips curve, quadratic objective function
% ZL-Q
if philflag==0 & prefflag==1
    % price and demand shocks
    if shocflag==2 | -1
        c=0.1;
        xpart1=c+((x+YSH)+zeta/2).^2;
        xpart2=c+(-(x+YSH)+zeta/2).^2;
        xzone=(x+YSH)-0.5*sqrt(xpart1)+0.5*sqrt(xpart2);
        ppxzone=p+alphaz.*xzone+PSH;
        finit=(((omega.*(ppxzone-pitarg).^2+(1-omega).*(x+YSH).^2)*wei)'*wei)./pi;
    % price shocks only    
    elseif shocflag==1
        c=0.1;
        xpart1=c+(x+zeta/2).^2;
        xpart2=c+(-x+zeta/2).^2;
        xzone=x-0.5*sqrt(xpart1)+0.5*sqrt(xpart2);
        ppxzone=p+alphaz.*xzone+PSH;
        finit=((omega.*(ppxzone-pitarg).^2+(1-omega).*x.^2)'*wei)./sqrt(pi);
    % without uncertainty    
    elseif shocflag==0
        c=0.1;
        xpart1=c+(x+zeta/2).^2;
        xpart2=c+(-x+zeta/2).^2;
        xzone=x-0.5*sqrt(xpart1)+0.5*sqrt(xpart2);
        ppxzone=p+alphaz.*xzone;
        finit=(omega.*(ppxzone-pitarg).^2+(1-omega).*x.^2);
    end
end