function fe=val12ghxxnext(x,parameter,p,pilag,vpp,plimits,PSH,YSH,weip,weiy,flags);
%-------------------
% USED BY: us12ghxx
%-------------------

% possible parameter values:
% linear Phillips curve
alpha=parameter(1);
% nonlinear Phillips curve
zeta=parameter(2);
alphaz=parameter(3);
% IS curve
rho=parameter(4); 
ksi=parameter(5);
rbar=parameter(6);
% loss function
omega=parameter(7); 
beta=parameter(8);
pitarg=parameter(9);
zetapr=parameter(10);
% variance of shocks
sigmap=parameter(11);
sigmay=parameter(12);

% settings
philflag=flags(3);
prefflag=flags(4);
shocflag=flags(6);

% quadrature weights
wei=weip;

% linear Phillips curve
% L
if philflag==1
    % price and demand shocks
    if shocflag==2 | -1
        pinext=p+alpha.*(x+YSH)+PSH;
    % price shocks only    
    elseif shocflag==1
        pinext=p+alpha.*x+PSH;
    % without uncertainty    
    elseif shocflag==0
        pinext=p+alpha.*x;
    end
end

% zone-linear Phillips curve
% ZL
if philflag==0
    % price and demand shocks
    if shocflag==2 | -1
        c=0.1;
        xpart1=c+((x+YSH)+zeta/2).^2;
        xpart2=c+(-(x+YSH)+zeta/2).^2; 
        xzone=(x+YSH)-0.5*sqrt(xpart1)+0.5*sqrt(xpart2);
        pinext=p+alphaz.*xzone+PSH;
    % price shocks only    
    elseif shocflag==1
        c=0.1;
        xpart1=c+(x+zeta/2).^2;
        xpart2=c+(-x+zeta/2).^2; 
        xzone=x-0.5*sqrt(xpart1)+0.5*sqrt(xpart2);
        pinext=p+alphaz.*xzone+PSH;
    % without uncertainty    
    elseif shocflag==0
        c=0.1;
        xpart1=c+(x+zeta/2).^2;
        xpart2=c+(-x+zeta/2).^2; 
        xzone=x-0.5*sqrt(xpart1)+0.5*sqrt(xpart2);
        pinext=p+alphaz.*xzone;
    end
end

% evaluate in between grid points by bilinear interpolation
[pinextrow,pinextcol]=size(pinext);
pinext=reshape(pinext,pinextrow*pinextcol,1);
vnext=myinterp1q(pilag,vpp,pinext);
vnext=reshape(vnext,pinextrow,pinextcol);
 
% integrate to obtain expectation of next period's value
% price and demand shocks
if shocflag==2 | -1
    evalue=((vnext*wei)'*wei)./pi;
% price shocks only
elseif shocflag==1
    evalue=(vnext'*wei)./sqrt(pi);
% without uncertainty
elseif shocflag==0
    evalue=vnext;
end
    
% compute current-period value by calling val12ghinit
revalue=val12ghxxinit(x,parameter,p,PSH,YSH,weip,weiy,flags);
    
% right-hand-side of the Bellman equation (to be maximized)
fe=revalue+beta.*evalue;